==> owncloud-4.5.4.tar.bz2: owncloud/core/l10n/oc.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Nom d'applicacion pas donat.",
"No category to add?" => "Pas de categoria d'ajustar ?",
"This category already exists: " => "La categoria exista ja :",
"Settings" => "Configuracion",
"January" => "Genièr",
"February" => "Febrièr",
"March" => "Març",
"April" => "Abril",
"May" => "Mai",
"June" => "Junh",
"July" => "Julhet",
"August" => "Agost",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Decembre",
"Choose" => "Causís",
"Cancel" => "Anulla",
"No" => "Non",
"Yes" => "Òc",
"Ok" => "D'accòrdi",
"No categories selected for deletion." => "Pas de categorias seleccionadas per escafar.",
"Error" => "Error",
"Error while sharing" => "Error al partejar",
"Error while unsharing" => "Error al non partejar",
"Error while changing permissions" => "Error al cambiar permissions",
"Shared with you and the group" => "Partejat amb tu e lo grop",
"by" => "per",
"Shared with you by" => "Partejat amb tu per",
"Share with" => "Parteja amb",
"Share with link" => "Parteja amb lo ligam",
"Password protect" => "Parat per senhal",
"Password" => "Senhal",
"Set expiration date" => "Met la data d'expiracion",
"Expiration date" => "Data d'expiracion",
"Share via email:" => "Parteja tras corrièl :",
"No people found" => "Deguns trobat",
"Resharing is not allowed" => "Tornar partejar es pas permis",
"Shared in" => "Partejat dins",
"with" => "amb",
"Unshare" => "Non parteje",
"can edit" => "pòt modificar",
"access control" => "Contraròtle d'acces",
"create" => "crea",
"update" => "met a jorn",
"delete" => "escafa",
"share" => "parteja",
"Password protected" => "Parat per senhal",
"Error unsetting expiration date" => "Error al metre de la data d'expiracion",
"Error setting expiration date" => "Error setting expiration date",
"ownCloud password reset" => "senhal d'ownCloud tornat botar",
"Use the following link to reset your password: {link}" => "Utiliza lo ligam seguent per tornar botar lo senhal : {link}",
"You will receive a link to reset your password via Email." => "Reçaupràs un ligam per tornar botar ton senhal via corrièl.",
"Requested" => "Requesit",
"Login failed!" => "Fracàs de login",
"Username" => "Nom d'usancièr",
"Request reset" => "Tornar botar requesit",
"Your password was reset" => "Ton senhal es estat tornat botar",
"To login page" => "Pagina cap al login",
"New password" => "Senhal nòu",
"Reset password" => "Senhal tornat botar",
"Personal" => "Personal",
"Users" => "Usancièrs",
"Apps" => "Apps",
"Admin" => "Admin",
"Help" => "Ajuda",
"Access forbidden" => "Acces enebit",
"Cloud not found" => "Nívol pas trobada",
"Edit categories" => "Edita categorias",
"Add" => "Ajusta",
"Create an <strong>admin account</strong>" => "Crea un <strong>compte admin</strong>",
"Advanced" => "Avançat",
"Data folder" => "Dorsièr de donadas",
"Configure the database" => "Configura la basa de donadas",
"will be used" => "serà utilizat",
"Database user" => "Usancièr de la basa de donadas",
"Database password" => "Senhal de la basa de donadas",
"Database name" => "Nom de la basa de donadas",
"Database tablespace" => "Espandi de taula de basa de donadas",
"Database host" => "Òste de basa de donadas",
"Finish setup" => "Configuracion acabada",
"web services under your control" => "Services web jos ton contraròtle",
"Log out" => "Sortida",
"Lost your password?" => "L'as perdut lo senhal ?",
"remember" => "bremba-te",
"Log in" => "Dintrada",
"You are logged out." => "Sias pas dintra (t/ada)",
"prev" => "dariièr",
"next" => "venent"
);

==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/oc.php <==
<?php
$TRANSLATIONS = array(
"Sunday" => "Dimenge",
"Monday" => "Diluns",
"Tuesday" => "Dimarç",
"Wednesday" => "Dimecres",
"Thursday" => "Dijòus",
"Friday" => "Divendres",
"Saturday" => "Dissabte",
"January" => "genièr",
"February" => "febrièr",
"March" => "març",
"April" => "abril",
"May" => "mai",
"June" => "junh",
"July" => "julhet",
"August" => "agost",
"September" => "septembre",
"October" => "octobre",
"November" => "Novembre",
"December" => "Decembre",
"Settings" => "Configuracion",
"Folder" => "Dorsièr",
"Saving..." => "Enregistra...",
"seconds ago" => "segonda a",
"_%n minute ago_::_%n minutes ago_" => array("",""),
"_%n hour ago_::_%n hours ago_" => array("",""),
"today" => "uèi",
"yesterday" => "ièr",
"_%n day ago_::_%n days ago_" => array("",""),
"last month" => "mes passat",
"_%n month ago_::_%n months ago_" => array("",""),
"last year" => "an passat",
"years ago" => "ans a",
"Reset password" => "Senhal tornat botar",
"Yes" => "Òc",
"No" => "Non",
"Choose" => "Causís",
"Ok" => "D'accòrdi",
"_{count} file conflict_::_{count} file conflicts_" => array("",""),
"Cancel" => "Annula",
"Share" => "Parteja",
"Error" => "Error",
"Error while sharing" => "Error al partejar",
"Error while unsharing" => "Error al non partejar",
"Error while changing permissions" => "Error al cambiar permissions",
"Password protect" => "Parat per senhal",
"Set expiration date" => "Met la data d'expiracion",
"Expiration date" => "Data d'expiracion",
"Share via email:" => "Parteja tras corrièl :",
"No people found" => "Deguns trobat",
"group" => "grop",
"Resharing is not allowed" => "Tornar partejar es pas permis",
"Unshare" => "Pas partejador",
"can edit" => "pòt modificar",
"access control" => "Contraròtle d'acces",
"create" => "crea",
"update" => "met a jorn",
"delete" => "escafa",
"Password protected" => "Parat per senhal",
"Error unsetting expiration date" => "Error al metre de la data d'expiracion",
"Error setting expiration date" => "Error setting expiration date",
"Delete" => "Escafa",
"Add" => "Ajusta",
"Use the following link to reset your password: {link}" => "Utiliza lo ligam seguent per tornar botar lo senhal : {link}",
"You will receive a link to reset your password via Email." => "Reçaupràs un ligam per tornar botar ton senhal via corrièl.",
"Username" => "Non d'usancièr",
"New password" => "Senhal novèl",
"Personal" => "Personal",
"Users" => "Usancièrs",
"Apps" => "Apps",
"Admin" => "Admin",
"Help" => "Ajuda",
"Access forbidden" => "Acces enebit",
"Cloud not found" => "Nívol pas trobada",
"Security Warning" => "Avertiment de securitat",
"Create an <strong>admin account</strong>" => "Crea un <strong>compte admin</strong>",
"Password" => "Senhal",
"Data folder" => "Dorsièr de donadas",
"Configure the database" => "Configura la basa de donadas",
"Database user" => "Usancièr de la basa de donadas",
"Database password" => "Senhal de la basa de donadas",
"Database name" => "Nom de la basa de donadas",
"Database tablespace" => "Espandi de taula de basa de donadas",
"Database host" => "Òste de basa de donadas",
"Finish setup" => "Configuracion acabada",
"Log out" => "Sortida",
"remember" => "bremba-te",
"Log in" => "Dintrada"
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
